@@ -9,14 +9,14 @@ with Java regular expression code.
 >>> r2 = re.compile('bc')
 >>> r3 = re.compile('abc')
 >>> fullmatch(r1, string)  # doctest: +ELLIPSIS
-<...SRE_Match object...>
+<...Match object...>
 >>> fullmatch(r2, string)
 >>> fullmatch(r3, string)
->>> r = re.compile('\\d{8}|\\d{10,11}')
+>>> r = re.compile(r'\\d{8}|\\d{10,11}')
 >>> m = fullmatch(r, '1234567890')
 >>> m.end()
 10
->>> r = re.compile(u('[+\uff0b\\d]'), re.UNICODE)
+>>> r = re.compile(u(r'[+\uff0b\\d]'), re.UNICODE)
 >>> m = fullmatch(r, u('\uff10'))
 >>> m.end()
 1
@@ -38,6 +38,7 @@ def fullmatch(pattern, string, flags=0):
         m = None  # pragma no cover
     return m
 
+
 if __name__ == '__main__':  # pragma no cover
     import doctest
     doctest.testmod()
